==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/Pdf3DViewCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class Pdf3DViewCollection(SpireObject):
    """
    Represents a collection of Pdf3DView objects. 
    """

    def Add(self, value: 'Pdf3DView') -> int:
        """
        Adds the specified value.

        Args:
            value: The value to add.

        Returns:
            int: The result of the addition.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DViewCollection_Add.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DViewCollection_Add.restype = c_int
        ret = GetDllLibPdf().Pdf3DViewCollection_Add(self.Ptr, intPtrvalue)
        return ret


    def Contains(self, value: 'Pdf3DView') -> bool:
        """
        Determines whether the collection contains the specified value.

        Args:
            value: The value to check.

        Returns:
            bool: True if the collection contains the specified value, False otherwise.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DViewCollection_Contains.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DViewCollection_Contains.restype = c_bool
        ret = GetDllLibPdf().Pdf3DViewCollection_Contains(self.Ptr, intPtrvalue)
        return ret


    def IndexOf(self, value: 'Pdf3DView') -> int:
        """
        Returns the index of the specified Pdf3DView object.

        Args:
            value: The value to find.

        Returns:
            int: The index of the specified value.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DViewCollection_IndexOf.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DViewCollection_IndexOf.restype = c_int
        ret = GetDllLibPdf().Pdf3DViewCollection_IndexOf(self.Ptr, intPtrvalue)
        return ret


    def Insert(self, index: int, value: 'Pdf3DView'):
        """
        Inserts the specified value at the specified index.

        Args:
            index: The index to insert the value at.
            value: The value to insert.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DViewCollection_Insert.argtypes = [c_void_p, c_int, c_void_p]
        GetDllLibPdf().Pdf3DViewCollection_Insert(self.Ptr, index, intPtrvalue)


    def Remove(self, value: 'Pdf3DView'):
        """
        Removes the specified value from the collection.

        Args:
            value: The Pdf3DView object to remove.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DViewCollection_Remove.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DViewCollection_Remove(self.Ptr, intPtrvalue)


    def get_Item(self, index: int) -> 'Pdf3DView':
        """
        Gets the Pdf3DView object at the specified index.

        Args:
            index: The index of the Pdf3DView object.

        Returns:
            Pdf3DView: The Pdf3DView object at the specified index.
        """
        
        GetDllLibPdf().Pdf3DViewCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().Pdf3DViewCollection_get_Item.restype = c_void_p
        intPtr = GetDllLibPdf().Pdf3DViewCollection_get_Item(self.Ptr, index)
        ret = None if intPtr == None else Pdf3DView(intPtr)
        return ret


    def set_Item(self, index: int, value: 'Pdf3DView'):
        """
        Sets the Pdf3DView object at the specified index.

        Args:
            index: The index to set the value at.
            value: The value to set.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DViewCollection_set_Item.argtypes = [c_void_p, c_int, c_void_p]
        GetDllLibPdf().Pdf3DViewCollection_set_Item(self.Ptr, index, intPtrvalue)

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/Pdf3DViewCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class Pdf3DViewCollection(SpireObject):
    """
    Represents a collection of Pdf3DView objects. 
    """

    def Add(self, value: 'Pdf3DView') -> int:
        """
        Adds the specified value.

        Args:
            value: The value to add.

        Returns:
            int: The result of the addition.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DViewCollection_Add.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DViewCollection_Add.restype = c_int
        ret = CallCFunction(GetDllLibPdf().Pdf3DViewCollection_Add,self.Ptr, intPtrvalue)
        return ret


    def Contains(self, value: 'Pdf3DView') -> bool:
        """
        Determines whether the collection contains the specified value.

        Args:
            value: The value to check.

        Returns:
            bool: True if the collection contains the specified value, False otherwise.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DViewCollection_Contains.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DViewCollection_Contains.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().Pdf3DViewCollection_Contains,self.Ptr, intPtrvalue)
        return ret


    def IndexOf(self, value: 'Pdf3DView') -> int:
        """
        Returns the index of the specified Pdf3DView object.

        Args:
            value: The value to find.

        Returns:
            int: The index of the specified value.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DViewCollection_IndexOf.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DViewCollection_IndexOf.restype = c_int
        ret = CallCFunction(GetDllLibPdf().Pdf3DViewCollection_IndexOf,self.Ptr, intPtrvalue)
        return ret


    def Insert(self, index: int, value: 'Pdf3DView'):
        """
        Inserts the specified value at the specified index.

        Args:
            index: The index to insert the value at.
            value: The value to insert.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DViewCollection_Insert.argtypes = [c_void_p, c_int, c_void_p]
        CallCFunction(GetDllLibPdf().Pdf3DViewCollection_Insert,self.Ptr, index, intPtrvalue)


    def Remove(self, value: 'Pdf3DView'):
        """
        Removes the specified value from the collection.

        Args:
            value: The Pdf3DView object to remove.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DViewCollection_Remove.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().Pdf3DViewCollection_Remove,self.Ptr, intPtrvalue)


    def get_Item(self, index: int) -> 'Pdf3DView':
        """
        Gets the Pdf3DView object at the specified index.

        Args:
            index: The index of the Pdf3DView object.

        Returns:
            Pdf3DView: The Pdf3DView object at the specified index.
        """
        
        GetDllLibPdf().Pdf3DViewCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().Pdf3DViewCollection_get_Item.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().Pdf3DViewCollection_get_Item,self.Ptr, index)
        ret = None if intPtr == None else Pdf3DView(intPtr)
        return ret


    def set_Item(self, index: int, value: 'Pdf3DView'):
        """
        Sets the Pdf3DView object at the specified index.

        Args:
            index: The index to set the value at.
            value: The value to set.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DViewCollection_set_Item.argtypes = [c_void_p, c_int, c_void_p]
        CallCFunction(GetDllLibPdf().Pdf3DViewCollection_set_Item,self.Ptr, index, intPtrvalue)
